@@ -24,7 +24,7 @@ class LidarScene:
     Scene properties:
       - cameras: List of cameras
       - frames: List of frames
-      - public_url: Url used to host the data in S3
+      - base_url: Url used to host the data in S3
 
     """
 
@@ -34,7 +34,7 @@ class LidarScene:
         """
         self.cameras: MutableMapping[LidarCamera] = pd.Series()
         self.frames: MutableMapping[LidarFrame] = pd.Series()
-        self.public_url = None
+        self.base_url = None
         self.scale_file_attachments = None
 
     def get_camera(self, camera_id=None, index: int = None) -> LidarCamera:
@@ -159,20 +159,20 @@ class LidarScene:
         for frame in self.frames:
             frame.transform = offset @ frame.transform
 
-    def to_dict(self, public_url: str = None) -> dict:
-        """Return a dictionary with the frame urls using the public_url as base.
+    def to_dict(self, base_url: str = None) -> dict:
+        """Return a dictionary with the frame urls using the base_url as base.
 
-        :param public_url: This url will be concatenated with the frames name, e.g.: `'%s/frame-%s.json' % (public_url, frame.id)`
-        :type public_url: str
+        :param base_url: This url will be concatenated with the frames name, e.g.: `'%s/frame-%s.json' % (base_url, frame.id)`
+        :type base_url: str
         :return: Dictionary with the frame urls data
         :rtype: dict
 
         """
-        if public_url is None:
-            public_url = self.public_url
+        if base_url is None:
+            base_url = self.base_url
         return dict(
             frames=[
-                "%s/frame-%s.json" % (public_url, frame.id) for frame in self.frames
+                "%s/frame-%s.json" % (base_url, frame.id) for frame in self.frames
             ]
         )
 
@@ -198,10 +198,10 @@ class LidarScene:
         :rtype: str
 
         """
-        self.public_url = f"s3://{bucket}/{path}"
+        self.base_url = f"s3://{bucket}/{path}"
 
-        print("Uploading scene to S3: %s" % self.public_url)
-        scene_dict = self.to_dict(self.public_url)
+        print("Uploading scene to S3: %s" % self.base_url)
+        scene_dict = self.to_dict(self.base_url)
 
         poses_csv = pd.DataFrame(
             self.frames.map(lambda f: list(f.transform.matrix.reshape(-1))).to_dict()
@@ -243,7 +243,7 @@ class LidarScene:
         signed_url = get_signed_url(bucket, path)
 
         print(f"Scene uploaded: {signed_url}")
-        return self.public_url
+        return self.base_url
 
     def scale_file_upload(
         self,
@@ -288,7 +288,7 @@ class LidarScene:
             # Save frames
             for frame in self.frames:
                 # Save points
-                data = frame.to_json(self.public_url)
+                data = frame.to_json(self.base_url)
                 out.writestr(
                     "frame-%s.json" % frame.id, data, compress_type=zipfile.ZIP_DEFLATED
                 )
